<!--
#
# Copyright (C) 2022 KTH Royal Institute of Technology Sweden
#
# invenio-config-kth is free software, you can redistribute it and/or
# modify it under the terms of the MIT License; see LICENSE file details.
-->
Changes
=======

Version 1.0.0 (released 2022-12-01)
Version 1.1.0 Add terms of use checkbox for Registration form